==> libslf4j-java_1.5.2.orig.tar.gz: libslf4j-java-1.5.2.orig/jcl-over-slf4j/src/test/java/org/apache/commons/logging/InvokeJCLTest.java <==
/*
 * Copyright (c) 2004-2005 SLF4J.ORG
 * Copyright (c) 2004-2005 QOS.ch
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute, and/or sell copies of  the Software, and to permit persons
 * to whom  the Software is furnished  to do so, provided  that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the  Software and  that both  the above  copyright notice(s)  and this
 * permission notice appear in supporting documentation.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR  A PARTICULAR PURPOSE AND NONINFRINGEMENT
 * OF  THIRD PARTY  RIGHTS. IN  NO EVENT  SHALL THE  COPYRIGHT  HOLDER OR
 * HOLDERS  INCLUDED IN  THIS  NOTICE BE  LIABLE  FOR ANY  CLAIM, OR  ANY
 * SPECIAL INDIRECT  OR CONSEQUENTIAL DAMAGES, OR  ANY DAMAGES WHATSOEVER
 * RESULTING FROM LOSS  OF USE, DATA OR PROFITS, WHETHER  IN AN ACTION OF
 * CONTRACT, NEGLIGENCE  OR OTHER TORTIOUS  ACTION, ARISING OUT OF  OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Except as  contained in  this notice, the  name of a  copyright holder
 * shall not be used in advertising or otherwise to promote the sale, use
 * or other dealings in this Software without prior written authorization
 * of the copyright holder.
 *
 */


package org.apache.commons.logging;

import junit.framework.TestCase;


public class InvokeJCLTest extends TestCase {

  public void testIsEnabledAPI() {
    // assume that we are running over slf4j-simple
    Log log = LogFactory.getLog(InvokeJCLTest.class);
    assertFalse(log.isTraceEnabled());
    assertFalse(log.isDebugEnabled());
    assertTrue(log.isInfoEnabled());
    assertTrue(log.isWarnEnabled());
    assertTrue(log.isErrorEnabled());
    assertTrue(log.isFatalEnabled());
  }
  
  public void testPrintAPI() {
    Log log = LogFactory.getLog(InvokeJCLTest.class);
    Exception e = new Exception("just testing");
  
    log.trace(null);
    log.trace("trace message");
    
    log.debug(null);
    log.debug("debug message");
    
    log.info(null);
    log.info("info  message");
    
    log.warn(null);
    log.warn("warn message");

    log.error(null);
    log.error("error message");

    log.fatal(null);
    log.fatal("fatal message");
    

    log.trace(null, e);
    log.trace("trace message", e);
    
    log.debug(null, e);
    log.debug("debug message", e);
    
    log.info(null, e);    
    log.info("info  message", e);
    
    log.warn(null, e);
    log.warn("warn message", e);
    
    log.error(null, e);
    log.error("error message", e);
    
    log.fatal(null, e);
    log.fatal("fatal message", e);
  }
}

==> libslf4j-java_1.5.11.orig.tar.gz: libslf4j-java-1.5.11.orig/jcl-over-slf4j/src/test/java/org/apache/commons/logging/InvokeJCLTest.java <==
/*
 * Copyright (c) 2004-2005 SLF4J.ORG
 * Copyright (c) 2004-2005 QOS.ch
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute, and/or sell copies of  the Software, and to permit persons
 * to whom  the Software is furnished  to do so, provided  that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the  Software and  that both  the above  copyright notice(s)  and this
 * permission notice appear in supporting documentation.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR  A PARTICULAR PURPOSE AND NONINFRINGEMENT
 * OF  THIRD PARTY  RIGHTS. IN  NO EVENT  SHALL THE  COPYRIGHT  HOLDER OR
 * HOLDERS  INCLUDED IN  THIS  NOTICE BE  LIABLE  FOR ANY  CLAIM, OR  ANY
 * SPECIAL INDIRECT  OR CONSEQUENTIAL DAMAGES, OR  ANY DAMAGES WHATSOEVER
 * RESULTING FROM LOSS  OF USE, DATA OR PROFITS, WHETHER  IN AN ACTION OF
 * CONTRACT, NEGLIGENCE  OR OTHER TORTIOUS  ACTION, ARISING OUT OF  OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Except as  contained in  this notice, the  name of a  copyright holder
 * shall not be used in advertising or otherwise to promote the sale, use
 * or other dealings in this Software without prior written authorization
 * of the copyright holder.
 *
 */


package org.apache.commons.logging;

import junit.framework.TestCase;


public class InvokeJCLTest extends TestCase {

  public void testIsEnabledAPI() {
    // assume that we are running over slf4j-jdk14
    Log log = LogFactory.getLog(InvokeJCLTest.class);
    assertFalse(log.isTraceEnabled());
    assertFalse(log.isDebugEnabled());
    assertTrue(log.isInfoEnabled());
    assertTrue(log.isWarnEnabled());
    assertTrue(log.isErrorEnabled());
    assertTrue(log.isFatalEnabled());
  }
  
  public void testPrintAPI() {
    Log log = LogFactory.getLog(InvokeJCLTest.class);
    Exception e = new Exception("just testing");
  
    log.trace(null);
    log.trace("trace message");
    
    log.debug(null);
    log.debug("debug message");
    
    log.info(null);
    log.info("info  message");
    
    log.warn(null);
    log.warn("warn message");

    log.error(null);
    log.error("error message");

    log.fatal(null);
    log.fatal("fatal message");
    

    log.trace(null, e);
    log.trace("trace message", e);
    
    log.debug(null, e);
    log.debug("debug message", e);
    
    log.info(null, e);    
    log.info("info  message", e);
    
    log.warn(null, e);
    log.warn("warn message", e);
    
    log.error(null, e);
    log.error("error message", e);
    
    log.fatal(null, e);
    log.fatal("fatal message", e);
  }
}
